Welcome to npTDMS's documentation
=================================

npTDMS is a cross-platform Python package for reading and writing TDMS files as produced by LabVIEW,
and is built on top of the `numpy <http://www.numpy.org/>`__ package.
Data read from a TDMS file is stored in numpy arrays,
and numpy arrays are also used when writing TDMS file.

Contents
========

.. toctree::
    quickstart
    reading
    writing
    apireference
    tdmsinfo
    limitations
